const fs = require('fs');
const path = require('path');
const child_exec = require('child_process').execSync;

// 执行终端命令
function exec (cmd, env) {
  return child_exec(cmd, {
    stdio: 'inherit',
    env: Object.assign({}, process.env, env)
  });
};

function getGitUser () {
  let name;
  let email;

  try {
    name = child_exec('git config --get user.name');
    email = child_exec('git config --get user.email');
  } catch (e) {}

  name = (name && name.toString().trim()) || '';
  email = (email && ` <${email.toString().trim()}>`) || '';

  return name + email;
}

function copy (origin, target) {
  if (!fs.existsSync(target)) {
    fs.mkdirSync(target);
  }

  fs.readdirSync(origin).forEach(file => {
    let originFile = path.join(origin, file);
    let targetFile = path.join(target, file.replace(/\.keep$/, ''));
    let stat = fs.statSync(originFile);

    if (stat.isDirectory()) {
      copy(originFile, targetFile);
    } else if (!fs.existsSync(targetFile)) {
      fs.writeFileSync(targetFile, fs.readFileSync(originFile), { encoding: 'utf8' });
    }
  });
}

exports.exec = exec;
exports.getGitUser = getGitUser;
exports.copy = copy;
